@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -427,7 +427,7 @@ gchar *version;
   };
 */
 
-	static const gchar *copyright = "Copyright \xc2\xa9 1995-2015 - Maxime DOYEN";
+	static const gchar *copyright = "Copyright \xc2\xa9 1995-2016 - Maxime DOYEN";
 
 
 
@@ -614,7 +614,8 @@ static void ui_mainwindow_action_defcategory(void)
 	ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_TITLE+UF_SENSITIVE));
 }
 
-static void ui_mainwindow_action_defarchive(void)
+
+static void ui_mainwindow_defarchive(Archive *arc)
 {
 struct hbfile_data *data;
 GtkTreeModel *model;
@@ -625,7 +626,7 @@ GtkTreeModel *model;
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_upc));
 	gtk_list_store_clear (GTK_LIST_STORE(model));
 
-	ui_arc_manage_dialog();
+	ui_arc_manage_dialog(arc);
 
 	ui_mainwindow_scheduled_populate(GLOBALS->mainwindow, NULL);
 
@@ -633,6 +634,12 @@ GtkTreeModel *model;
 }
 
 
+static void ui_mainwindow_action_defarchive(void)
+{
+	ui_mainwindow_defarchive(NULL);
+}
+
+
 static void ui_mainwindow_action_defbudget(void)
 {
 	ui_bud_manage_dialog();
@@ -1360,6 +1367,23 @@ GtkTreeIter			 iter;
 }
 
 
+static void ui_mainwindow_scheduled_onRowActivated (GtkTreeView        *treeview,
+                       GtkTreePath        *path,
+                       GtkTreeViewColumn  *col,
+                       gpointer            userdata)
+{
+//struct hbfile_data *data;
+Archive *arc;
+
+	DB( g_print ("\n[ui-mainwindow] A scheduled row has been double-clicked!\n") );
+
+	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(treeview, GTK_TYPE_WINDOW)), "inst_data");
+
+	arc = ui_mainwindow_scheduled_get_selected_item(treeview);
+	ui_mainwindow_defarchive(arc);
+}
+
+
 static void ui_mainwindow_scheduled_do_post(Archive *arc, gboolean doedit, gpointer user_data)
 {
 struct hbfile_data *data = user_data;
@@ -1408,7 +1432,7 @@ struct hbfile_data *data = user_data;
 	if( (arc != NULL) )
 	{
 		ui_mainwindow_scheduled_do_post(arc, TRUE, data);
-		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_REFRESHALL));
+		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE|UF_REFRESHALL));
 	}
 }
 
@@ -1428,8 +1452,8 @@ struct hbfile_data *data = user_data;
 			da_transaction_init_from_template(txn, arc);
 			txn->date = scheduled_get_postdate(arc, arc->nextdate);
 			transaction_add(txn, NULL, 0);
+
 			GLOBALS->changes_count++;
-		
 			scheduled_date_advance(arc);
 
 			da_transaction_free (txn);
@@ -1439,7 +1463,7 @@ struct hbfile_data *data = user_data;
 			ui_mainwindow_scheduled_do_post(arc, FALSE, data);
 		}
 
-		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_REFRESHALL));
+		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE|UF_REFRESHALL));
 	}
 }
 
@@ -1451,9 +1475,11 @@ struct hbfile_data *data = user_data;
 	Archive *arc = ui_mainwindow_scheduled_get_selected_item(GTK_TREE_VIEW(data->LV_upc));
 	if( (arc != NULL) && (arc->flags & OF_AUTO) )
 	{
+		GLOBALS->changes_count++;
 		scheduled_date_advance(arc);
 
 		ui_mainwindow_scheduled_populate(GLOBALS->mainwindow, NULL);
+		ui_mainwindow_update(GLOBALS->mainwindow, GINT_TO_POINTER(UF_SENSITIVE));
 	}
 }
 
@@ -2083,7 +2109,7 @@ gint flags;
 		sensitive = da_cat_length() > 1 ? TRUE : FALSE;
 		gtk_action_set_sensitive(gtk_ui_manager_get_action(data->manager, "/MenuBar/ManageMenu/Budget"), sensitive);
 
-		//#1501129 no need to disable, P & C can be created from assigne dialog
+		//#1501129 no need to disable, P & C can be created from assign dialog
 		//sensitive = ((da_cat_length() > 1) || (da_pay_length() > 1)) ? TRUE : FALSE;
 		//gtk_action_set_sensitive(gtk_ui_manager_get_action(data->manager, "/MenuBar/ManageMenu/Assign"), sensitive);
 
@@ -2910,6 +2936,7 @@ GtkWidget *bar, *label;
 	g_signal_connect (GTK_TREE_VIEW(data->LV_acc), "row-activated", G_CALLBACK (ui_mainwindow_onRowActivated), GINT_TO_POINTER(2));
 
 	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_upc)), "changed", G_CALLBACK (ui_mainwindow_scheduled_selection_cb), NULL);
+	g_signal_connect (GTK_TREE_VIEW(data->LV_upc), "row-activated", G_CALLBACK (ui_mainwindow_scheduled_onRowActivated), NULL);
 	g_signal_connect (G_OBJECT (data->BT_sched_skip), "clicked", G_CALLBACK (ui_mainwindow_scheduled_skip_cb), data);
 	g_signal_connect (G_OBJECT (data->BT_sched_editpost), "clicked", G_CALLBACK (ui_mainwindow_scheduled_editpost_cb), data);
 	g_signal_connect (G_OBJECT (data->BT_sched_post), "clicked", G_CALLBACK (ui_mainwindow_scheduled_post_cb), data);
@@ -2932,9 +2959,7 @@ GtkWidget *bar, *label;
 
 	//gtk_action_group_set_sensitive(data->actions, FALSE);
 
-
 	
-  return window;
+	return window;
 }
 
-
