@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2014 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -107,6 +107,7 @@ Payee *pay;
 	{
 		g_warning("arc consistency: fixed invalid cat %d", item->kcat);
 		item->kcat = 0;
+		GLOBALS->changes_count++;
 	}
 
 	// check payee exists
@@ -115,19 +116,20 @@ Payee *pay;
 	{
 		g_warning("arc consistency: fixed invalid pay %d", item->kpay);
 		item->kpay = 0;
+		GLOBALS->changes_count++;
 	}
 
 	// reset dst acc for non xfer transaction
 	if( item->paymode != PAYMODE_INTXFER )
 		item->kxferacc = 0;
 
-	// remove automation if dst_acc not exists
+	// delete automation if dst_acc not exists
 	if(item->paymode == PAYMODE_INTXFER)
 	{
 		acc = da_acc_get(item->kxferacc);
 		if(acc == NULL)
 		{
-			item->flags &= ~(OF_AUTO);	//remove flag
+			item->flags &= ~(OF_AUTO);	//delete flag
 		}
 	}
 
@@ -135,11 +137,35 @@ Payee *pay;
 
 /* = = = = = = = = = = = = = = = = = = = = */
 
+Archive *da_archive_init_from_transaction(Archive *arc, Transaction *txn)
+{
+	//fill it
+	arc->amount		= txn->amount;
+	arc->kacc		= txn->kacc;
+	arc->kxferacc	= txn->kxferacc;
+	arc->paymode		= txn->paymode;
+	arc->flags			= txn->flags	& (OF_INCOME);
+	arc->status		= txn->status;
+	arc->kpay			= txn->kpay;
+	arc->kcat		= txn->kcat;
+	if(txn->wording != NULL)
+		arc->wording 		= g_strdup(txn->wording);
+	else
+		arc->wording 		= g_strdup(_("(new archive)"));
+
+	return arc;
+}
+
+
+
+
 static guint32 _sched_date_get_next_post(Archive *arc, guint32 nextdate)
 {
 GDate *tmpdate;
 guint32 nextpostdate = nextdate;
-	
+
+	DB( g_print("\n[scheduled] _sched_date_get_next_post\n") );
+
 	tmpdate = g_date_new_julian(nextpostdate);
 	switch(arc->unit)
 	{
@@ -161,17 +187,6 @@ guint32 nextpostdate = nextdate;
 	nextpostdate = g_date_get_julian(tmpdate);
 	g_date_free(tmpdate);
 	
-	/* check limit, update and maybe break */
-	if(arc->flags & OF_LIMIT)
-	{
-		arc->limit--;
-		if(arc->limit <= 0)
-		{
-			arc->flags ^= (OF_LIMIT | OF_AUTO);	// invert flags
-			nextpostdate = 0;
-		}
-	}
-
 	return nextpostdate;
 }
 
@@ -195,6 +210,9 @@ GDateWeekday wday;
 guint32 finalpostdate;
 gint shift;
 
+	DB( g_print("\n[scheduled] scheduled_get_postdate\n") );
+
+
 	finalpostdate = postdate;
 	
 	tmpdate = g_date_new_julian(finalpostdate);
@@ -237,19 +255,20 @@ gint shift;
 
 guint32 scheduled_get_latepost_count(Archive *arc, guint32 jrefdate)
 {
-guint32 nbpost = 0;
-guint32 curdate = arc->nextdate;
+guint32 nblate = 0;
+guint32 curdate;
 	
+	curdate = arc->nextdate;
 	while(curdate <= jrefdate)
 	{
 		curdate = _sched_date_get_next_post(arc, curdate);
-		nbpost++;
-		// break at 11 max (to display +10)
-		if(nbpost >= 11)
+		nblate++;
+		// break if over limit or at 11 max (to display +10)
+		if(nblate >= arc->limit || nblate >= 11)
 			break;
 	}
 
-	return nbpost;
+	return nblate;
 }
 
 
@@ -257,6 +276,19 @@ guint32 curdate = arc->nextdate;
 guint32 scheduled_date_advance(Archive *arc)
 {
 	arc->nextdate = _sched_date_get_next_post(arc, arc->nextdate);
+	
+	//#1556289
+	/* check limit, update and maybe break */
+	if(arc->flags & OF_LIMIT)
+	{
+		arc->limit--;
+		if(arc->limit <= 0)
+		{
+			arc->flags ^= (OF_LIMIT | OF_AUTO);	// invert flags
+			arc->nextdate = 0;
+		}
+	}
+	
 	return arc->nextdate;
 }
 
