@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -39,8 +39,6 @@ extern struct HomeBank *GLOBALS;
 extern struct Preferences *PREFS;
 
 
-static GList *transaction_xfer_get_potential_child(Transaction *ope);
-
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 void
@@ -168,6 +166,7 @@ guint count;
 	return new_item;
 }
 
+
 GList *
 da_transaction_new(void)
 {
@@ -371,169 +370,13 @@ guint i, nbsplit;
 	//if( item->flags & OF_VALID )
 	//	item->flags &= ~(OF_REMIND);
 
-
-	// check child xfer #1464961
-	//remove for 5.0.5: this cause some trouble to some people
-	//so let's keep the data insane...
-	/*if( item->paymode == PAYMODE_INTXFER )
-	{
-	Transaction *child;
-	GList *matchlist;
-	gint count;
-	
-		child = transaction_strong_get_child_transfer (item);
-		if(child == NULL)
-		{
-			matchlist = transaction_xfer_get_potential_child(item);
-			count = g_list_length (matchlist);
-			if( count == 0 )
-			{
-				transaction_xfer_create_child(item, NULL);
-				g_warning("txn consistency: fixed invalid child xfer");
-			}
-			else
-			{
-				item->paymode = PAYMODE_XFER;
-				item->kxfer = 0;
-				item->kxferacc = 0;
-			}
-			GLOBALS->changes_count++;
-			g_list_free(matchlist);
-		}
-	}*/
-
 }
 
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 /* new transfer functions */
 
-
-
-
-//todo: add strong control and extend to payee, maybe memo ?
-static gboolean transaction_is_child_xfer(Transaction *stxn, Transaction *dtxn, gint daygap)
-{
-gboolean retval = FALSE;
-
-	if(stxn == dtxn)
-		return FALSE;
-
-	if( stxn->date == dtxn->date &&
-	    stxn->kxferacc == dtxn->kacc &&
-	    ABS(stxn->amount) == ABS(dtxn->amount) &&
-	    dtxn->kxfer == 0)
-	{
-		retval = TRUE;
-	}
-	return retval;
-}
-
-
-static GList *transaction_xfer_get_potential_child(Transaction *ope)
-{
-GList *list;
-GList *matchlist = NULL;
-
-	DB( g_print("\n[transaction]xfer_get_potential_child\n") );
-
-	//DB( g_print(" - search : %d %s %f %d=>%d\n", src->date, src->wording, src->amount, src->account, src->kxferacc) );
-
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
-	{
-	Transaction *item = list->data;
-
-		if( transaction_is_child_xfer(ope, item, 0) == TRUE )
-		{
-			//DB( g_print(" - match : %d %s %f %d=>%d\n", item->date, item->wording, item->amount, item->account, item->kxferacc) );
-
-			matchlist = g_list_append(matchlist, item);
-		}
-		list = g_list_next(list);
-	}
-
-	DB( g_print(" - found : %d\n", g_list_length(matchlist)) );
-
-	return matchlist;
-}
-
-
-void transaction_xfer_search_or_add_child(Transaction *ope, GtkWidget *treeview)
-{
-GList *matchlist;
-gint count;
-
-	DB( g_print("\n[transaction] transaction_xfer_search_or_add_child\n") );
-
-	matchlist = transaction_xfer_get_potential_child(ope);
-	count = g_list_length(matchlist);
-
-	DB( g_print(" - found result is %d, switching\n", count) );
-
-	switch(count)
-	{
-		case 0:		//we should create the child
-			transaction_xfer_create_child(ope, treeview);
-			break;
-
-		//todo: maybe with just 1 match the user must choose ?
-		//#942346: bad idea so to no let the user confirm, so let him confirm
-		/*
-		case 1:		//transform the transaction to a child transfer
-		{
-			GList *list = g_list_first(matchlist);
-			transaction_xfer_change_to_child(ope, list->data);
-			break;
-		}
-		*/
-
-		default:	//the user must choose himself
-		{
-		Transaction *child;
-
-			child = ui_dialog_transaction_xfer_select_child(treeview, matchlist);
-			if(child == NULL)
-				transaction_xfer_create_child(ope, treeview);
-			else
-				transaction_xfer_change_to_child(ope, child);
-			break;
-		}
-	}
-
-	g_list_free(matchlist);
-
-}
-
-
-Transaction *transaction_strong_get_child_transfer(Transaction *src)
-{
-GList *list;
-
-	DB( g_print("\n[transaction] transaction_strong_get_child_transfer\n") );
-
-	DB( g_print(" - search: %d %s %f %d=>%d\n", src->date, src->wording, src->amount, src->kacc, src->kxferacc) );
-
-	list = g_list_first(GLOBALS->ope_list);
-	while (list != NULL)
-	{
-	Transaction *item = list->data;
-
-		//#1252230
-		//if( item->paymode == PAYMODE_INTXFER && item->kacc == src->kxferacc && item->kxfer == src->kxfer )
-		if( item->paymode == PAYMODE_INTXFER && item->kxfer == src->kxfer && item != src )
-		{
-			DB( g_print(" - found : %d %s %f %d=>%d\n", item->date, item->wording, item->amount, item->kacc, item->kxferacc) );
-			return item;
-		}
-		list = g_list_next(list);
-	}
-	DB( g_print(" - not found...\n") );
-	return NULL;
-}
-
-
-void transaction_xfer_create_child(Transaction *ope, GtkWidget *treeview)
+static void transaction_xfer_create_child(Transaction *ope)
 {
 Transaction *child;
 Account *acc;
@@ -543,8 +386,12 @@ gchar swap;
 
 	if( ope->kxferacc > 0 )
 	{
+		
 		child = da_transaction_clone(ope);
 
+		ope->flags |= OF_CHANGED;
+		child->flags |= OF_ADDED;
+
 		child->amount = -child->amount;
 		child->flags ^= (OF_INCOME);	// invert flag
 		//#1268026
@@ -579,29 +426,143 @@ gchar swap;
 
 			account_balances_add (child);
 
-			if(treeview != NULL)
-				transaction_add_treeview(child, treeview, ope->kacc);
 		}
 	}
 
 }
 
 
+//todo: add strong control and extend to payee, maybe memo ?
+static gboolean transaction_xfer_child_might(Transaction *stxn, Transaction *dtxn, gint daygap)
+{
+gboolean retval = FALSE;
+
+	if(stxn == dtxn)
+		return FALSE;
+
+	if( 
+		stxn->date == dtxn->date &&
+	    //stxn->kxferacc == dtxn->kacc &&
+		stxn->kacc != dtxn->kacc &&
+	    ABS(stxn->amount) == ABS(dtxn->amount) &&
+	    dtxn->kxfer == 0)
+	{
+		retval = TRUE;
+	}
+
+	return retval;
+}
+
+
+static GList *transaction_xfer_child_might_list_get(Transaction *ope)
+{
+GList *list;
+GList *matchlist = NULL;
+
+	DB( g_print("\n[transaction]xfer_get_potential_child\n") );
+
+	//DB( g_print(" - search : %d %s %f %d=>%d\n", src->date, src->wording, src->amount, src->account, src->kxferacc) );
+
+	list = g_list_first(GLOBALS->ope_list);
+	while (list != NULL)
+	{
+	Transaction *item = list->data;
+
+		if( transaction_xfer_child_might(ope, item, 0) == TRUE )
+		{
+			//DB( g_print(" - match : %d %s %f %d=>%d\n", item->date, item->wording, item->amount, item->account, item->kxferacc) );
+
+			matchlist = g_list_append(matchlist, item);
+		}
+		list = g_list_next(list);
+	}
+
+	DB( g_print(" - found : %d\n", g_list_length(matchlist)) );
+
+	return matchlist;
+}
+
+
+void transaction_xfer_search_or_add_child(GtkWindow *parentwindow, Transaction *ope)
+{
+GList *matchlist;
+
+	DB( g_print("\n[transaction] transaction_xfer_search_or_add_child\n") );
+
+	matchlist = transaction_xfer_child_might_list_get(ope);
+
+	DB( g_print(" - found result is %d, switching\n", count) );
+
+	Transaction *child;
+
+		child = ui_dialog_transaction_xfer_select_child(parentwindow, ope, matchlist);
+		if(child == NULL)
+			transaction_xfer_create_child(ope);
+		else
+			transaction_xfer_change_to_child(ope, child);
+
+
+	g_list_free(matchlist);
+}
+
+
+Transaction *transaction_xfer_child_strong_get(Transaction *src)
+{
+Account *dstacc;
+GList *list;
+
+	DB( g_print("\n[transaction] transaction_xfer_child_strong_get\n") );
+
+	dstacc = da_acc_get(src->kxferacc);
+	if( !dstacc || src->kxfer <= 0 )
+		return NULL;
+
+	DB( g_print(" - search: %d %s %f %d=>%d\n", src->date, src->wording, src->amount, src->kacc, src->kxferacc) );
+
+	list = g_list_first(GLOBALS->ope_list);
+	while (list != NULL)
+	{
+	Transaction *item = list->data;
+
+		//#1252230
+		//if( item->paymode == PAYMODE_INTXFER 
+		//	&& item->kacc == src->kxferacc
+		//	&& item->kxfer == src->kxfer )
+		if( item->paymode == PAYMODE_INTXFER 
+		 && item->kxfer == src->kxfer 
+		 && item != src )
+		{
+			DB( g_print(" - found : %d %s %f %d=>%d\n", item->date, item->wording, item->amount, item->kacc, item->kxferacc) );
+			return item;
+		}
+		list = g_list_next(list);
+	}
+	
+	DB( g_print(" - not found...\n") );
+	return NULL;
+}
+
+
+
+
 void transaction_xfer_change_to_child(Transaction *ope, Transaction *child)
 {
-Account *acc;
+Account *dstacc;
 
 	DB( g_print("\n[transaction] transaction_xfer_change_to_child\n") );
 
+	ope->flags |= OF_CHANGED;
+	child->flags |= OF_CHANGED;
+
 	child->paymode = PAYMODE_INTXFER;
 
 	ope->kxferacc = child->kacc;
 	child->kxferacc = ope->kacc;
 
 	/* update acc flags */
-	acc = da_acc_get( child->kacc);
-	if(acc != NULL)
-		acc->flags |= AF_CHANGED;
+	dstacc = da_acc_get( child->kacc);
+	if(dstacc != NULL)
+		dstacc->flags |= AF_CHANGED;
 
 	//strong link
 	guint maxkey = da_transaction_get_max_kxfer();
@@ -651,7 +612,7 @@ Transaction *dst;
 
 	DB( g_print("\n[transaction] transaction_xfer_remove_child\n") );
 
-	dst = transaction_strong_get_child_transfer( src );
+	dst = transaction_xfer_child_strong_get( src );
 
 	DB( g_print(" -> return is %s, %p\n", dst->wording, dst) );
 
@@ -777,7 +738,7 @@ Account *acc;
 
 		if(newope->paymode == PAYMODE_INTXFER)
 		{
-			transaction_xfer_search_or_add_child(newope, treeview);
+			transaction_xfer_search_or_add_child(NULL, newope);
 		}
 	}
 }
