@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -17,14 +17,14 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+
 #ifndef __HB_TRANSACTION_H__
 #define __HB_TRANSACTION_H__
 
 
-
-
 typedef struct _transaction	Transaction;
 
+
 #include "hb-split.h"
 
 struct _transaction
@@ -49,6 +49,7 @@ struct _transaction
 
 	/* unsaved datas */
 	GList		*same;		//used for import todo: change this
+
 	gdouble		balance;
 };
 
@@ -103,9 +104,8 @@ guint da_transaction_length(void);
 void transaction_add_treeview(Transaction *ope, GtkWidget *treeview, guint32 accnum);
 void transaction_add(Transaction *ope, GtkWidget *treeview, guint32 accnum);
 
-Transaction *transaction_strong_get_child_transfer(Transaction *src);
-void transaction_xfer_search_or_add_child(Transaction *ope, GtkWidget *treeview);
-void transaction_xfer_create_child(Transaction *ope, GtkWidget *treeview);
+Transaction *transaction_xfer_child_strong_get(Transaction *src);
+void transaction_xfer_search_or_add_child(GtkWindow *parentwindow, Transaction *ope);
 void transaction_xfer_change_to_child(Transaction *ope, Transaction *child);
 void transaction_xfer_sync_child(Transaction *ope, Transaction *child);
 void transaction_xfer_remove_child(Transaction *src);
