@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -71,9 +71,9 @@
 
 #define HB_VERSION_MAJOR	5
 #define HB_VERSION_MINOR	0
-#define HB_VERSION_MICRO	6
+#define HB_VERSION_MICRO	7
 
-#define HB_VERSION			"5.0.6"
+#define HB_VERSION			"5.0.7"
 #define HB_VERSION_NUM	(HB_VERSION_MAJOR*10000) + (HB_VERSION_MINOR*100) + HB_VERSION_MICRO
 
 #define FILE_VERSION		1.1
@@ -87,6 +87,7 @@
 	#define HB_DATA_PATH	"homebank_unstable"
 #endif
 
+
 #ifdef G_OS_WIN32
 	#define GETTEXT_PACKAGE "homebank"
 	#define LOCALE_DIR      "locale"
@@ -121,11 +122,12 @@
 
 /* miscellaneous */
 #define PHI 1.61803399
-	/* official GTK_RESPONSE are negative */
+
+/* official GTK_RESPONSE are negative */
 #define GTK_RESPONSE_ADD		 1
 #define GTK_RESPONSE_ADDKEEP	 2
 
-#define HB_NUMBER_SAMPLE	20457.99
+#define HB_NUMBER_SAMPLE	1234567.89
 
 
 enum
@@ -168,16 +170,20 @@ enum
 #define ICONNAME_PREFERENCES		"preferences-system"	  //obsolete
 #define ICONNAME_REFRESH			"view-refresh"		
 
-#define ICONNAME_HB_TOGGLE_SIGN		"toggle-sign-symbolic"
+
 
 
 
 //#define ICONNAME_HB_SCHED_SKIP		"media-skip-forward"
 //#define ICONNAME_HB_SCHED_POST		"media-playback-start"
 
-#define ICONNAME_HB_BUTTON_MENU		"open-menu-symbolic"	//gnome not found
+// custom or gnome not found
+#define ICONNAME_HB_BUTTON_MENU		"open-menu-symbolic"
+#define ICONNAME_HB_TOGGLE_SIGN		"toggle-sign-symbolic"
+
 
 /* -------- named icons (Custom to homebank) -------- */
+
 #define ICONNAME_HB_ACCOUNT         "hb-account"
 #define ICONNAME_HB_ARCHIVE         "hb-archive"
 #define ICONNAME_HB_ASSIGN          "hb-assign"
@@ -216,6 +222,7 @@ enum
 #define ICONNAME_HB_OPE_ADD         "hb-ope-add"	//? "edit-add"
 #define ICONNAME_HB_OPE_HERIT       "hb-ope-herit"  //? "edit-clone"
 #define ICONNAME_HB_OPE_EDIT        "hb-ope-edit"   //
+#define ICONNAME_HB_OPE_MULTIEDIT   "hb-ope-multiedit"   //
 #define ICONNAME_HB_OPE_DELETE      "hb-ope-delete" //? "edit-delete"
 #define ICONNAME_CONVERT			"hb-ope-convert"
 #define ICONNAME_HB_ASSIGN_RUN      "hb-assign-run"
