@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -182,17 +182,17 @@ static EuroParams euro_params[] =
 	{ "EEK", "Estonia"       , 15.6466  , "kr"  , FALSE, ",", " ", 2  },	//
 /* 2014 */
 	{ "LVL", "Latvia"        , 0.702804 , "lat.", FALSE, ",", "" , 2  },	// jan. 2014
-/* 2015 */
-	{ "LTL", "Lithuania"     , 3.45280	, "Lt." , TRUE , ",", "" , 2  },	// jan. 2015
+/* 2016 */
+	{ "LTL", "Lithuania"     , 3.45280	, "Lt." , TRUE , ",", "" , 2  },	// jan. 2016
 
 /* future */
 	{ "BGN", "Bulgaria"      , 1.95583	, "лв." , TRUE , ",", " ", 2  },	// non-fixé - 2014 target for euro
 	{ "HUF", "Hungary"       , 261.51	, "Ft"  , TRUE , ",", " ", 2  },	// non-fixé - No current target for euro
-	{ "RON", "Romania"       , 3.5155	, "Leu" , FALSE, ",", ".", 2  },	// non-fixé - 2015 target for euro earliest
-	{ "CZK", "Czech republic", 28.36	, "Kč"  , FALSE, ",", " ", 2  },	// non-fixé - 2015 earliest
-	{ "HRK", "Croatia"       , 1.0000   , "kn"  , FALSE, "" , ".", 0  },	// non-fixé - 2015 target for euro earliest
+	{ "RON", "Romania"       , 3.5155	, "Leu" , FALSE, ",", ".", 2  },	// non-fixé - 2016 target for euro earliest
+	{ "CZK", "Czech republic", 28.36	, "Kč"  , FALSE, ",", " ", 2  },	// non-fixé - 2016 earliest
+	{ "HRK", "Croatia"       , 1.0000   , "kn"  , FALSE, "" , ".", 0  },	// non-fixé - 2016 target for euro earliest
 	{ "PLN", "Poland"        , 0.25     , "zł"  , FALSE, ",", "" , 2  },	// non-fixé - No current target for euro
-	
+
 //	{ "   ", ""    , 1.00000	, ""   , ""  , FALSE, ",", "", 2  },
 	
 };
@@ -596,52 +596,6 @@ guint i;
 	return combobox;
 }
 
-/*
-static defpref_currency_display(GtkWidget *widget, gpointer user_data)
-{
-struct defpref_data *data;
-struct iso4217format *curfmt;
-
-	DB( g_print("\n[ui-pref] display default currency\n") );
-
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
-	curfmt =  iso4217format_get(PREFS->curr_default);
-	if(curfmt != NULL)
-	{
-	gchar *name = g_strdup_printf("%s (%s)", curfmt->curr_iso_code, iso4217_get_name(curfmt->curr_iso_code));
-	
-		gtk_label_set_label (data->LB_default, name);
-		g_free(name);
-	}
-
-}
-
-
-static void defpref_currency_change(GtkWidget *widget, gpointer user_data)
-{
-struct defpref_data *data;
-struct iso4217format *curfmt;
-
-	DB( g_print("\n[ui-pref] chnage default currency\n") );
-
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
-	curfmt = ui_cur_select_dialog_new(data->window);
-
-	DB( g_print("(cur) return  %s\n", curfmt) );
-
-	if( curfmt != NULL )
-	{
-		g_free(PREFS->curr_default);
-		PREFS->curr_default = g_strdup(curfmt->culture);
-		
-		defpref_currency_display(widget, NULL);
-	}
-
-}
-*/
-
 
 static void defpref_pathselect(GtkWidget *widget, gpointer user_data)
 {
@@ -720,7 +674,6 @@ GDate *date;
 }
 
 
-
 /*
 ** update the number sample label
 */
@@ -870,6 +823,23 @@ gint country;
 
 }
 
+
+static void defpref_colortoggle(GtkWidget *widget, gpointer user_data)
+{
+struct defpref_data *data;
+gboolean sensitive;
+
+	DB( g_print("\n[ui-pref] color toggle\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	sensitive = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_custom_colors));
+
+	gtk_widget_set_sensitive(data->GR_colors	 , sensitive);
+
+}
+
+
 /*
 ** set preset colors for amount display
 */
@@ -922,7 +892,17 @@ gchar *expcol, *inccol, *wrncol;
 }
 
 
+static void defpref_color_scheme_changed(GtkWidget *widget, gpointer user_data)
+{
+struct defpref_data *data;
 
+	DB( g_print("\n[ui-pref] color scheme chnaged\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	gtk_widget_queue_draw (data->DA_colors);
+	
+}
 
 
 
@@ -947,15 +927,6 @@ guint	tmp;
 /*
 ** set :: fill in widgets from PREFS structure
 */
-static void defpref_entry_set_text(GtkWidget *widget, gchar *text)
-{
-	DB( g_print(" set text to '%s'\n", text) );
-
-	if( text != NULL )
-	{
-		gtk_entry_set_text(GTK_ENTRY(widget), text);
-	}
-}
 
 static void defpref_set(struct defpref_data *data)
 {
@@ -1002,10 +973,10 @@ GdkRGBA rgba;
 	/* display */
 	gtk_entry_set_text(GTK_ENTRY(data->ST_datefmt), PREFS->date_format);
 
-	defpref_entry_set_text(data->ST_num_symbol, PREFS->base_cur.symbol);
+	ui_gtk_entry_set_text(data->ST_num_symbol, PREFS->base_cur.symbol);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_num_isprefix), PREFS->base_cur.is_prefix);
-	defpref_entry_set_text(data->ST_num_decimalchar, PREFS->base_cur.decimal_char);
-	defpref_entry_set_text(data->ST_num_groupingchar, PREFS->base_cur.grouping_char);
+	ui_gtk_entry_set_text(data->ST_num_decimalchar, PREFS->base_cur.decimal_char);
+	ui_gtk_entry_set_text(data->ST_num_groupingchar, PREFS->base_cur.grouping_char);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_num_fracdigits), PREFS->base_cur.frac_digits);
 
 	//gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_numnbdec), PREFS->num_nbdecimal);
@@ -1018,7 +989,7 @@ GdkRGBA rgba;
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_daterange_txn), PREFS->date_range_txn);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_datefuture_nbdays), PREFS->date_future_nbdays);
 	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_daterange_rep), PREFS->date_range_rep);
-	
+
 	/* euro */
 	//defpref_currency_display(data->LB_default, NULL);
 	
@@ -1031,10 +1002,10 @@ GdkRGBA rgba;
 
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_euro_value), PREFS->euro_value);
 
-	defpref_entry_set_text(data->ST_euro_symbol, PREFS->minor_cur.symbol);
+	ui_gtk_entry_set_text(data->ST_euro_symbol, PREFS->minor_cur.symbol);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix), PREFS->minor_cur.is_prefix);
-	defpref_entry_set_text(data->ST_euro_decimalchar, PREFS->minor_cur.decimal_char);
-	defpref_entry_set_text(data->ST_euro_groupingchar, PREFS->minor_cur.grouping_char);
+	ui_gtk_entry_set_text(data->ST_euro_decimalchar, PREFS->minor_cur.decimal_char);
+	ui_gtk_entry_set_text(data->ST_euro_groupingchar, PREFS->minor_cur.grouping_char);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->NB_euro_fracdigits), PREFS->minor_cur.frac_digits);
 
 
@@ -1063,35 +1034,6 @@ GdkRGBA rgba;
 ** get :: fill PREFS structure from widgets
 */
 
-
-static void defpref_entry_get_text(GtkWidget *widget, gchar **storage)
-{
-const gchar *text;
-
-
-	DB( g_print("defpref_entry_get_text\n") );
-
-	DB( g_print(" storage is '%p' at '%p'\n", *storage, storage) );
-
-	/* free any previous string */
-	if( *storage != NULL )
-	{
-		DB( g_print(" storage was not null, freeing\n") );
-
-		g_free(*storage);
-
-	}
-
-	*storage = NULL;
-
-	text = gtk_entry_get_text(GTK_ENTRY(widget));
-	*storage = g_strdup(text);
-	DB( g_print(" storing %s at %p\n", *storage, storage) );
-
-	DB( g_print(" get text to '%s' '%s'\n", text, *storage) );
-}
-
-
 #define RGBA_TO_INT(x) (int)(x*255)
 
 static gchar *gdk_rgba_to_hex(GdkRGBA *rgba)
@@ -1142,9 +1084,9 @@ const gchar *lang;
 	g_free(PREFS->path_hbfile);
 	PREFS->path_hbfile = g_strdup(gtk_entry_get_text(GTK_ENTRY(data->ST_path_hbfile)));
 
-	defpref_entry_get_text(data->ST_path_import, &PREFS->path_import);
+	ui_gtk_entry_replace_text(data->ST_path_import, &PREFS->path_import);
 
-	defpref_entry_get_text(data->ST_path_export, &PREFS->path_export);
+	ui_gtk_entry_replace_text(data->ST_path_export, &PREFS->path_export);
 
 	PREFS->loadlast  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_load_last));
 	PREFS->appendscheduled  = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_append_scheduled));
@@ -1159,10 +1101,10 @@ const gchar *lang;
 	g_free(PREFS->date_format);
 	PREFS->date_format = g_strdup(gtk_entry_get_text(GTK_ENTRY(data->ST_datefmt)));
 
-	defpref_entry_get_text(data->ST_num_symbol, &PREFS->base_cur.symbol);
+	ui_gtk_entry_set_text(data->ST_num_symbol, PREFS->base_cur.symbol);
 	PREFS->base_cur.is_prefix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_num_isprefix));
-	defpref_entry_get_text(data->ST_num_decimalchar, &PREFS->base_cur.decimal_char);
-	defpref_entry_get_text(data->ST_num_groupingchar, &PREFS->base_cur.grouping_char);
+	ui_gtk_entry_set_text(data->ST_num_decimalchar, PREFS->base_cur.decimal_char);
+	ui_gtk_entry_set_text(data->ST_num_groupingchar, PREFS->base_cur.grouping_char);
 	PREFS->base_cur.frac_digits = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_num_fracdigits));
 
 	//PREFS->num_nbdecimal = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_numnbdec));
@@ -1183,7 +1125,7 @@ const gchar *lang;
 	//PREFS->euro_nbdec = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->NB_euro_nbdec));
 	//PREFS->euro_thsep = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_thsep));
 
-	defpref_entry_get_text(data->ST_euro_symbol, &PREFS->minor_cur.symbol);
+	ui_gtk_entry_replace_text(data->ST_euro_symbol, &PREFS->minor_cur.symbol);
 	PREFS->minor_cur.is_prefix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_euro_isprefix));
 	
 	g_free(PREFS->minor_cur.decimal_char);
@@ -1231,7 +1173,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 	
 	row = 1;
-	label = make_label(_("Date order:"), 0, 0.5);
+	label = make_label_widget(_("Date order:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_cycle(label, CYA_IMPORT_DATEORDER);
@@ -1250,7 +1192,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 	
 	row = 1;
-	label = make_label(_("_Memo field:"), 0, 0.5);
+	label = make_label_widget(_("_Memo field:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_cycle(label, CYA_IMPORT_OFXMEMO);
@@ -1269,7 +1211,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 	
 	row = 1;
-	label = make_label(_("_Import:"), 0, 0.5);
+	label = make_label_widget(_("_Import:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 
@@ -1279,6 +1221,7 @@ gint crow, row;
 
 	widget = make_string(label);
 	data->ST_path_import = widget;
+	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(widget)), GTK_STYLE_CLASS_LINKED);
 	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
 	widget = gtk_button_new_with_label("...");
@@ -1286,7 +1229,7 @@ gint crow, row;
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 
 	row++;
-	label = make_label(_("_Export:"), 0, 0.5);
+	label = make_label_widget(_("_Export:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 
@@ -1296,6 +1239,7 @@ gint crow, row;
 
 	widget = make_string(label);
 	data->ST_path_export = widget;
+	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(widget)), GTK_STYLE_CLASS_LINKED);
 	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
 	widget = gtk_button_new_with_label("...");
@@ -1305,6 +1249,37 @@ gint crow, row;
 	return content_grid;
 }
 
+#define cube_dim 16
+
+static gboolean
+draw_callback (GtkWidget *widget,
+               cairo_t   *cr,
+               gpointer   user_data)
+{
+struct defpref_data *data = user_data;
+gint index;
+GtkColorScheme scheme;
+gint w, h;
+gint i, x, y;
+
+	index = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_color_scheme));
+
+	colorscheme_init(&scheme, index);
+	
+	gtk_widget_get_size_request (widget, &w, &h);
+	x = y = 0;
+	for(i=0;i<scheme.nb_cols;i++)
+	{
+		cairo_user_set_rgbcol (cr, &scheme.colors[i]);
+		cairo_rectangle(cr, x, y, cube_dim, cube_dim);
+		cairo_fill(cr);
+		x += 1 + cube_dim;
+		if( i == 15 )
+		{ x = 0; y = 1 + cube_dim; }
+	}
+
+	return TRUE;
+}
 
 
 
@@ -1328,7 +1303,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 	
 	row = 1;
-	label = make_label(_("Date _range:"), 0, 0.5);
+	label = make_label_widget(_("Date _range:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_daterange(label, FALSE);
@@ -1346,7 +1321,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 	
 	row = 1;
-	label = make_label(_("Color Scheme:"), 0, 0.5);
+	label = make_label_widget(_("Color Scheme:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_cycle(label, chart_colors);
@@ -1354,6 +1329,14 @@ gint crow, row;
 	//gtk_grid_attach (GTK_GRID (group_grid), data->CY_option[FILTER_DATE], 1, 2, row, row+1);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
+	row++;
+	widget = gtk_drawing_area_new ();
+	data->DA_colors = widget;
+	gtk_widget_set_size_request (widget, (1+cube_dim)*16, (1+cube_dim)*2);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+	g_signal_connect (data->DA_colors, "draw", G_CALLBACK (draw_callback), data);
+
 	// group :: Statistics options
     group_grid = gtk_grid_new ();
 	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
@@ -1459,7 +1442,7 @@ gint crow, row;
 	label = make_label(_("Value:"), 0, 0.5);
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
-	widget = make_euro(label);
+	widget = make_exchange_rate (label);
 	data->NB_euro_value = widget;
 	//gtk_grid_attach (GTK_GRID (group_grid), data->CY_option[FILTER_DATE], 1, 2, row, row+1);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
@@ -1666,7 +1649,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
 	row = 1;
-	label = make_label(_("Date _range:"), 0, 0.5);
+	label = make_label_widget(_("Date _range:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_daterange(label, FALSE);
@@ -1674,7 +1657,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_Show:"), 0, 0.5);
+	label = make_label_widget(_("_Show:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_numeric(NULL, 0, 366);
@@ -1689,12 +1672,12 @@ gint crow, row;
 	row++;
 	widget = gtk_check_button_new_with_mnemonic (_("Hide reconciled transactions"));
 	data->CM_hide_reconciled = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 2, 1);
 
 	row++;
 	widget = gtk_check_button_new_with_mnemonic (_("Always show remind transactions"));
 	data->CM_show_remind = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 2, 1);
 
 	// group :: Multiple add
     group_grid = gtk_grid_new ();
@@ -1756,14 +1739,14 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
 	row = 1;
-	label = make_label(_("_Language:"), 0, 0.5);
+	label = make_label_widget(_("_Language:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = ui_language_combobox_new(label);
 	data->CY_language = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 	
 	row++;
-	label = make_label(_("_Toolbar:"), 0, 0.5);
+	label = make_label_widget(_("_Toolbar:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_cycle(label, CYA_TOOLBAR_STYLE);
 	data->CY_toolbar = widget;
@@ -1787,10 +1770,16 @@ gint crow, row;
 	row = 1;
 	widget = gtk_check_button_new_with_mnemonic (_("Uses custom colors"));
 	data->CM_custom_colors = widget;
-	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
+
+    group_grid = gtk_grid_new ();
+	data->GR_colors = group_grid;
+	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
+	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
+	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
 
 	row++;
-	label = make_label(_("_Preset:"), 0, 0.5);
+	label = make_label_widget(_("_Preset:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_cycle(label, CYA_TANGO_COLORS);
@@ -1799,7 +1788,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 
 	row++;
-	label = make_label(_("_Expense:"), 0, 0.5);
+	label = make_label_widget(_("_Expense:"));
 	//----------------------------------------- l, r, t, b
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
@@ -1809,20 +1798,20 @@ gint crow, row;
 	data->CP_exp_color = widget;
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 	
-	label = make_label(_("_Income:"), 0, 0.5);
+	label = make_label_widget(_("_Income:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	widget = gtk_color_button_new ();
 	data->CP_inc_color = widget;
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
 
-	label = make_label(_("_Warning:"), 0, 0.5);
+	label = make_label_widget(_("_Warning:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	widget = gtk_color_button_new ();
 	data->CP_warn_color = widget;
 	gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
-	
+
 	return content_grid;
 }
 
@@ -1866,13 +1855,13 @@ gint crow, row;
 	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
 	gtk_grid_set_column_spacing (GTK_GRID (group_grid), SPACING_MEDIUM);
 	gtk_grid_attach (GTK_GRID (content_grid), group_grid, 0, crow++, 1, 1);
-	
+
 	label = make_label_group(_("Fiscal year"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
 	row = 1;
 	//TRANSLATORS: (fiscal year) starts on
-	label = make_label(_("Starts _on:"), 0.0, 0.5);
+	label = make_label_widget(_("Starts _on:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
@@ -1894,7 +1883,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
 	row = 1;
-	label = make_label(_("Date _range:"), 0, 0.5);
+	label = make_label_widget(_("Date _range:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 	widget = make_daterange(label, FALSE);
 	data->CY_daterange_wal = widget;
@@ -1910,7 +1899,7 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), label, 0, 0, 3, 1);
 
 	row = 1;
-	label = make_label(_("_Default:"), 0, 0.5);
+	label = make_label_widget(_("_Default:"));
 	gtk_grid_attach (GTK_GRID (group_grid), label, 1, row, 1, 1);
 
 	hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
@@ -1919,6 +1908,7 @@ gint crow, row;
 
 	widget = make_string(label);
 	data->ST_path_hbfile = widget;
+	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(widget)), GTK_STYLE_CLASS_LINKED);
 	gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
 	widget = gtk_button_new_with_label("...");
@@ -2094,7 +2084,7 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 	gtk_widget_show (hbox);
 
 	label = gtk_label_new (NULL);
-	gtk_widget_set_margin_start(label, SPACING_MEDIUM);
+	gtk_widget_set_margin_left(label, SPACING_MEDIUM);
 	gimp_label_set_attributes (GTK_LABEL (label),
                              PANGO_ATTR_SCALE,  PANGO_SCALE_XX_LARGE,
                              PANGO_ATTR_WEIGHT, PANGO_WEIGHT_BOLD,
@@ -2170,6 +2160,7 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 	g_signal_connect (data.BT_path_import, "pressed", G_CALLBACK (defpref_pathselect), GINT_TO_POINTER(2));
 	g_signal_connect (data.BT_path_export, "pressed", G_CALLBACK (defpref_pathselect), GINT_TO_POINTER(3));
 
+	g_signal_connect (data.CM_custom_colors, "toggled", G_CALLBACK (defpref_colortoggle), NULL);
     g_signal_connect (data.CY_colors, "changed", G_CALLBACK (defpref_colorpreset), NULL);
 
 
@@ -2183,6 +2174,10 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 	//date
     g_signal_connect (data.ST_datefmt, "changed", G_CALLBACK (defpref_date_sample), NULL);
 
+	//report
+	g_signal_connect (data.CY_color_scheme, "changed", G_CALLBACK (defpref_color_scheme_changed), NULL);
+
+
 	//base number
     g_signal_connect (data.ST_num_symbol   , "changed", G_CALLBACK (defpref_numberbase_sample), NULL);
 	g_signal_connect (data.CM_num_isprefix, "toggled", G_CALLBACK (defpref_numberbase_sample), NULL);
@@ -2204,10 +2199,11 @@ GtkWidget *hbox, *vbox, *sw, *widget, *notebook, *page, *ebox, *image, *label;
 	//defhbfile_setup(&data);
 	//defhbfile_update(data.LV_arc, NULL);
 
-	defpref_eurotoggle(window, NULL);
-
 	defpref_set(&data);
 
+	defpref_colortoggle(window, NULL);
+	defpref_eurotoggle(window, NULL);
+
 	gtk_window_resize(GTK_WINDOW(window), 640, 256);
 
 
@@ -2284,7 +2280,6 @@ gint i;
 	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
-	//gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (view), TRUE);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW (view), FALSE);
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), GTK_SELECTION_SINGLE);
 
