@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2015 Maxime DOYEN
+ *  Copyright (C) 1995-2016 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -540,6 +540,90 @@ gint n_arc;
 /*
 ** called from outside
 */
+gint deftransaction_external_edit(GtkWindow *parent, Transaction *old_txn, Transaction *new_txn)
+{
+GtkWidget *dialog;
+gboolean result;
+
+	dialog = create_deftransaction_window(GTK_WINDOW(parent), TRANSACTION_EDIT_MODIFY, FALSE);
+	deftransaction_set_transaction(dialog, new_txn);
+
+	result = gtk_dialog_run (GTK_DIALOG (dialog));
+	if(result == GTK_RESPONSE_ACCEPT)
+	{
+		deftransaction_get(dialog, NULL);
+
+		account_balances_sub(old_txn);
+		account_balances_add(new_txn);
+
+		if( new_txn->paymode == PAYMODE_INTXFER )
+		{
+			//nota: if kxfer is 0, the user may have just changed the paymode to xfer
+			DB( g_print(" - kxfer = %d\n", new_txn->kxfer) );
+
+			if(new_txn->kxfer > 0)	//1) search a strong linked child
+			{
+			Transaction *ltxn;
+
+				DB( g_print(" - old_txn: kacc=%d kxferacc=%d\n", old_txn->kacc, old_txn->kxferacc) );
+				
+				ltxn = transaction_xfer_child_strong_get(old_txn);
+				if(ltxn != NULL) //should never be the case
+				{
+					DB( g_print(" - strong link found, do sync\n") );
+					transaction_xfer_sync_child(new_txn, ltxn);
+				}
+				else
+				{
+					DB( g_print(" - no, somethin' went wrong here...\n") );
+				}
+			}
+			else
+			{
+				//2) any standard transaction that match ?
+				transaction_xfer_search_or_add_child(GTK_WINDOW(dialog), new_txn);
+			}
+		}
+
+		//#1250061 : manage ability to break an internal xfer
+		if(old_txn->paymode == PAYMODE_INTXFER && new_txn->paymode != PAYMODE_INTXFER)
+		{
+		GtkWidget *p_dialog;
+		gboolean break_result;
+			
+			DB( g_print(" - should break internal xfer\n") );
+
+			p_dialog = gtk_message_dialog_new
+			(
+				GTK_WINDOW(parent),
+				GTK_DIALOG_MODAL,
+				GTK_MESSAGE_WARNING,
+				GTK_BUTTONS_YES_NO,
+				_("Do you want to break the internal transfer ?\n\n"
+				  "Proceeding will delete the target transaction.")
+			);
+
+			break_result = gtk_dialog_run( GTK_DIALOG( p_dialog ) );
+			gtk_widget_destroy( p_dialog );
+
+			if(break_result == GTK_RESPONSE_YES)
+			{
+				transaction_xfer_remove_child(old_txn);
+			}
+			else	//force paymode to internal xfer
+			{
+				new_txn->paymode = PAYMODE_INTXFER;
+			}
+		}
+	}
+	
+	deftransaction_dispose(dialog, NULL);
+	gtk_widget_destroy (dialog);
+
+	return result;
+}
+
+
 void deftransaction_set_transaction(GtkWidget *widget, Transaction *ope)
 {
 struct deftransaction_data *data;
@@ -831,13 +915,15 @@ gint crow;
 		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_MEDIUM);
 		gtk_container_add (GTK_CONTAINER (expander), hbox);
 
-		label = make_label(_("_Template:"), 0, 0.5);
+		label = make_label_widget(_("_Template:"));
 		widget = make_poparchive(label);
 		data->PO_arc = widget;
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 		gtk_box_pack_start (GTK_BOX (hbox), widget, TRUE, TRUE, 0);
 
 		g_signal_connect (data->PO_arc, "changed", G_CALLBACK (deftransaction_fillfrom), NULL);
+
+		gtk_widget_show_all(expander);
 	}
 
 	//connect all our signals
